uncomplicate.illamanati.internal.onnxrt.gemma3


cuda-defaultclj

The default model configuration of the ONNX Runtime CUDA Execution Provider.

The default model configuration of the ONNX Runtime CUDA Execution Provider.
raw docstring

gemma-3-defaultclj

Configuration map of the Gemma 3 model exported to be compatible with onnxrunime-genai Gemma 3.

Configuration map of the Gemma 3 model exported to be compatible with onnxrunime-genai Gemma 3.
raw docstring

gemma-3-genai-cpuclj

Configuration map of the CPU model exported to be compatible with onnxrunime-genai Gemma3. https://huggingface.co/onnxruntime/Gemma-3-ONNX

Configuration map of the CPU model exported to be compatible with onnxrunime-genai Gemma3.
https://huggingface.co/onnxruntime/Gemma-3-ONNX
raw docstring

gemma-3-genai-cudaclj

Configuration map of the CUDA model exported to be compatible with onnxrunime-genai Gemma3. https://huggingface.co/onnxruntime/Gemma-3-ONNX

Configuration map of the CUDA model exported to be compatible with onnxrunime-genai Gemma3.
https://huggingface.co/onnxruntime/Gemma-3-ONNX
raw docstring

gemma-3-gqa-optimumclj

Configuration map of the cpu model exported to be compatible with onnx-community Gemma3 1b model. https://huggingface.co/onnx-community/gemma-3-1b-it-ONNX-GQA

Configuration map of the cpu model exported to be compatible with onnx-community Gemma3 1b model.
https://huggingface.co/onnx-community/gemma-3-1b-it-ONNX-GQA
raw docstring

gemma-3-optimumclj

Configuration map of the cpu model exported to be compatible with onnx-community Gemma3 4b model. https://huggingface.co/onnx-community/gemma-3-4b-it-ONNX

Configuration map of the cpu model exported to be compatible with onnx-community Gemma3 4b model.
https://huggingface.co/onnx-community/gemma-3-4b-it-ONNX
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries